@@ -1,4 +1,4 @@
-"hr.rast" <- function(mcp, w)
+"hr.rast" <- function(mcp, w, border=c("include", "exclude"))
 {
     ## Verifications
     if (inherits(w, "asc"))
@@ -7,6 +7,7 @@
       stop("Non convenient data")
     if (!inherits(mcp, "area"))
       stop("mcp should be of class \"area\"")
+    bord <- match.arg(border)
 
     ## a list with one element = one polygon
     lpc<-split(mcp[,2:3], mcp[,1])
@@ -14,7 +15,7 @@
 
     ## use of the function mcp.rast for each polygon
     for (i in 1:length(lpc))
-      output[[names(lpc)[i]]]<-mcp.rast(lpc[[i]], w)
+      output[[names(lpc)[i]]]<-mcp.rast(lpc[[i]], w, bord)
 
     ## the output:
     output<-as.kasc(output)
